@@ -124,7 +124,7 @@
 ##'   further analysis.
 ##'
 ##' An openair output can be manipulated using a number of generic operations,
-##'   including \code{print}, \code{plot} and \code{summary}. 
+##'   including \code{print}, \code{plot} and \code{summary}.
 ##' @author David Carslaw
 ##' @seealso See Also as \code{\link{windRose}}, \code{\link{pollutionRose}},
 ##'   \code{\link{polarFreq}}, \code{\link{polarPlot}}
@@ -152,19 +152,19 @@
 ##'
 ##'
 percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "default",
-                            percentile = c(25, 50, 75, 90, 95), smooth = FALSE, 
+                            percentile = c(25, 50, 75, 90, 95), smooth = FALSE,
                             method = "default", cols = "default",
                             mean = TRUE, mean.lty = 1, mean.lwd = 3, mean.col = "grey",
                             fill = TRUE, intervals = NULL, angle.scale = 45,
                             auto.text = TRUE,  key.header = NULL,
                             key.footer = "percentile", key.position = "bottom",
                             key = TRUE,  ...)
-  
+
 {
-  
+
   ## get rid of R check annoyances
   sub <- NULL
-  
+
   ## calculate percetiles or just show mean?
   if (is.na(percentile[1])) {
     mean.only <- TRUE
@@ -172,38 +172,38 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
   } else {
     mean.only <- FALSE
   }
-  
+
   if (tolower(method) == "cpf") {
     mean <- FALSE
     if (length(percentile) > 1) stop ("Only one percentile should be supplied when method = 'CPF'.")
   }
-  
+
   vars <- c(wd, pollutant)
   if (any(type %in%  dateTypes)) vars <- c(vars, "date")
-  
+
   mydata <- checkPrep(mydata, vars, type, remove.calm = FALSE, wd = wd)
   ## round wd
   mydata[, wd] <- 10 * ceiling(mydata[, wd] / 10 - 0.5)
-  
+
   ## make sure all wds are present
   ids <- which(!seq(10, 360, by = 10) %in% unique(mydata[, wd]))
   if (length(ids) > 0 & smooth != TRUE) {
-    
+
     extra <- mydata[rep(1, length(ids)), ]
     extra[, wd] <- seq(10, 360, by = 10)[ids]
     extra[, pollutant] <- NA
     mydata <- rbind(mydata, extra)
   }
-  
+
   ## need lowest value if shading
   if (fill) percentile <- unique(c(0, percentile))
-  
+
   ## if more than one pollutant, need to stack the data and set type = "variable"
   ## this case is most relevent for model-measurement compasrions where data are in columns
   ## Can also do more than one pollutant and a single type that is not "default", in which
   ## case pollutant becomes a conditioning variable
   if (length(pollutant) > 1) {
-    
+
     if (length(type) > 1) {
       warning(paste("Only type = '", type[1], "' will be used", sep = ""))
       type <- type[1]
@@ -217,13 +217,13 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
     } else {
       type <- c(type, "variable")
     }
-    
+
   }
-  
-  
+
+
   ##extra.args setup
   extra.args <- list(...)
-  
+
   #label controls
   extra.args$xlab <- if ("xlab" %in% names(extra.args))
     quickText(extra.args$xlab, auto.text) else quickText("", auto.text)
@@ -231,73 +231,75 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
     quickText(extra.args$ylab, auto.text) else quickText("", auto.text)
   extra.args$main <- if ("main" %in% names(extra.args))
     quickText(extra.args$main, auto.text) else quickText("", auto.text)
-  
+
   ## layout default
   if (!"layout" %in% names(extra.args))
     extra.args$layout <- NULL
-  
+
   ## lwd handling
   if (!"lwd" %in% names(extra.args))
     extra.args$lwd <- 2
-  
+
   ## mydata <- na.omit(mydata)
   id <- which(is.na(mydata[, wd]))
   if (length(id) > 0)
       mydata <- mydata[-id, ]
-  
+
   ## greyscale handling
   if (length(cols) == 1 && cols == "greyscale") {
-    
+
     trellis.par.set(list(strip.background = list(col = "white")))
   }
-  
+
   ## reset strip color on exit
   current.strip <- trellis.par.get("strip.background")
   on.exit(trellis.par.set("strip.background", current.strip))
-  
+
   if (!fill) { ## labels depend on whether line or area are used
     theLabels <- percentile
   } else {
     values <- cbind(percentile[-length(percentile)], percentile[-1])
     theLabels <- paste(values[ , 1], "-", values[ , 2], sep = "")
   }
-  
-  prepare.grid <- function(mydata, stat) {
+
+  prepare.grid <- function(mydata, stat, overall.lower, overall.upper) {
     #wd = NULL
     ## add zero wind angle = same as 360 for cyclic spline
     ids <- which(mydata[ , wd] == 360)
-    
-    if (length(ids) > 0) {
-      zero.wd <- mydata[ids, ]
-      zero.wd[, wd] <- 0
-      mydata <- rbind.fill(mydata, zero.wd)
-    }
-    
-    mod.percentiles <- function(i, mydata) {
+
+
+     if (length(ids) > 0) {
+       zero.wd <- mydata[ids, ]
+       zero.wd[, wd] <- 0
+       mydata <- rbind.fill(mydata, zero.wd)
+     }
+
+    mod.percentiles <- function(i, mydata, overall.lower, overall.upper) {
       ## need to work out how many knots to use in smooth
       thedata <- subset(percentiles, percentile == i)
-      
-      
+
+
       if (smooth) {
           min.dat <- min(thedata)
-        
+
         ## fit a spline through the data; making sure it goes through each wd value
         spline.res <- spline(x = thedata[ , wd], y = thedata[, pollutant], n = 361,
                              method = "natural")
-        
+
         pred <- data.frame(percentile = i, wd = 0:360, pollutant = spline.res$y)
-        
+
         ## don't let interpolated percentile be lower than data
         pred$pollutant[pred$pollutant < min.dat] <- min.dat
-        
+
         ## only plot where there are valid wd
         wds <- unique(percentiles[, wd])
         ids <- lapply(wds, function(x) seq(from = x - 5, to = x + 5))
         ids <- unique(do.call(c, ids))
         ids[ids < 0] <- ids[ids < 0] + 360
         pred$pollutant[-ids] <- min(c(0, min(percentiles[ , pollutant], na.rm = TRUE)))
-        
+
       } else {
+
         ## do not smooth
           dat1 <- thedata
           dat2 <- thedata
@@ -310,58 +312,66 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
         thedata[, wd][id] <- 0
         id <- which(thedata[, wd] == 365)
         thedata[, wd][id] <- 0
-       
+
         thedata <- thedata[order(thedata$id), ]
         thedata$pollutant <- thedata[, eval(pollutant)]
           pred <- thedata
-        
+
       }
       pred
     }
+
     if (method == "default") {
+
       ## calculate percentiles
-      percentiles <- ddply(mydata, wd, numcolwise(function (x) 
+      percentiles <- ddply(mydata, wd, numcolwise(function (x)
         quantile(x, probs = percentile / 100, na.rm = TRUE)))
       percentiles$percentile <- percentile
-      
+
     }
-    
+
     if (tolower(method) == "cpf") {
-      
-      ## overall percentile
-      overall.upper <- quantile(mydata[, pollutant], probs = max(percentile) / 100, na.rm = TRUE)
-      overall.lower <- quantile(mydata[, pollutant], probs = min(percentile) / 100, na.rm = TRUE)
-      
-      percentiles1 <- ddply(mydata, wd, numcolwise(function (x) length(which(x < overall.lower)) / length(x)))
+
+      percentiles1 <- ddply(mydata, wd, numcolwise(function (x)
+                                                   length(which(x < overall.lower)) /
+                                                   length(x)))
       percentiles1$percentile <- min(percentile)
-      
-      percentiles2 <- ddply(mydata, wd, numcolwise(function (x) length(which(x > overall.upper)) / length(x)))
+
+      percentiles2 <- ddply(mydata, wd, numcolwise(function (x)
+                                                   length(which(x > overall.upper)) /
+                                                   length(x)))
       percentiles2$percentile <- max(percentile)
-      
+
       if (fill) {
         percentiles <- rbind(percentiles1, percentiles2)
       } else {
         percentiles <- percentiles2
       }
-      
+
     }
-    
-    
-    results <- ldply(percentile, mod.percentiles)
-    
+
+
+    results <- ldply(percentile, mod.percentiles, overall.lower, overall.upper)
+
     ## calculate mean; assume a percentile of 999 to flag it later
     percentiles <- ddply(mydata, wd, numcolwise(function (x) mean(x, na.rm = TRUE)))
     percentiles$percentile <- 999
     Mean <- ldply(999, mod.percentiles)
-    
+
     if (stat == "percentile") results <- results else results <- Mean
     results
   }
-  
-  
+
+
   mydata <- cutData(mydata, type, ...)
-  results.grid <- ddply(mydata, type, prepare.grid, stat = "percentile")
-  
+
+  ## overall.lower and overall.upper are the OVERALL upper/lower percentiles
+  overall.lower <-  quantile(mydata[, pollutant], probs = min(percentile) / 100, na.rm = TRUE)
+  overall.upper =  quantile(mydata[, pollutant], probs = max(percentile) / 100, na.rm = TRUE)
+
+  results.grid <- ddply(mydata, type, prepare.grid, stat = "percentile",
+                        overall.lower, overall.upper)
+
   if (method == "cpf") {
     ## useful labelling
     sub <- paste("CPF at the ", max(percentile),
@@ -369,56 +379,56 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
                  round(max(quantile(mydata[, pollutant], probs = percentile / 100,
                                     na.rm = TRUE)), 1), ")", sep = "")
   }
-  
-  
+
+
   if (mean) {
     Mean <- ddply(mydata, type, prepare.grid, stat = "mean")
-    
+
     results.grid <- rbind(results.grid, Mean)
   }
-  
+
   ## proper names of labelling ###################################################
   strip.dat <- strip.fun(results.grid, type, auto.text)
   strip <- strip.dat[[1]]
   strip.left <- strip.dat[[2]]
   pol.name <- strip.dat[[3]]
-  
+
   col <- openColours(cols, length(theLabels))
-  
+
   legend <- list(col = col, space = key.position, auto.text = auto.text,
                  labels = theLabels, footer = key.footer, header = key.header,
                  height = 0.60, width = 1.5, fit = "scale",
                  plot.style =  "other")
   legend <- makeOpenKeyLegend(key, legend, "percentileRose")
-  
+
   if (mean.only || tolower(method) == "cpf") legend <- NULL
-  
+
   temp <- paste(type, collapse = "+")
   myform <- formula(paste("y ~ x | ", temp, sep = ""))
-  
+
   ## keep unstransformed copy in case data are negative
   results <- results.grid
-  
+
   results.grid$x <- results.grid$pollutant * sin(results.grid[, wd] * pi / 180)
   results.grid$y <- results.grid$pollutant * cos(results.grid[, wd] * pi / 180)
- 
-  
+
+
   min.res <- min(results.grid$pollutant, na.rm = TRUE)
-  
+
   newdata <- results.grid ## data to return
-  
+
   ## nice intervals for pollutant concentrations
   tmp <- (results.grid$x ^ 2 + results.grid$y ^ 2) ^ 0.5
   if (missing(intervals)) intervals <- pretty(c(min(tmp, na.rm = TRUE), max(tmp, na.rm = TRUE)))
-  
-  
-  
+
+
+
   labs <- intervals ## the labels
-  
+
   ## if negative data, add to make all postive to plot properly
   min.int <- min(intervals, na.rm = TRUE)
   zero <- NA
-  
+
   if (min.int < 0 ) {
     zero <- which(intervals == 0) ## the zero line
     intervals <- intervals + -1 * min.int
@@ -426,10 +436,10 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
     results.grid <- transform(results, x = pollutant * sin(eval(wd) * pi / 180),
                               y = pollutant * cos(eval(wd) * pi / 180))
   }
-  
+
   ## re-label if CPF plot
   if (tolower(method) == "cpf") pollutant <- "probability"
-  
+
   xyplot.args <- list(x = myform,
                       xlim = c(max(intervals) * -1, max(intervals) * 1),
                       ylim = c(max(intervals) * -1, max(intervals) * 1),
@@ -442,56 +452,56 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
                       aspect = 1,
                       par.strip.text = list(cex = 0.8),
                       scales = list(draw = FALSE),...,
-                      
+
                       panel = function(x, y, subscripts, ...) {
-                        
+
                         if (fill) { ## filled polygons
-                          
+
                           for (i in rev(seq_along(percentile))) {
                             value <- percentile[i]
-                            
+
                             if (i == 1) {
                               subdata <- subset(results.grid[subscripts, ], percentile == value)
                              lpolygon(subdata$x, subdata$y, col = "white", border = NA)
-                              
+
                             } else {
-                              
+
                               subdata1 <- subset(results.grid[subscripts, ], percentile == value)
                               value2 <- percentile[i - 1]
                               subdata2 <- subset(results.grid[subscripts, ],
                                                  percentile == value2)
-                          
+
                               poly.na(x1 = subdata1$x, x2 = subdata2$x, y1 = subdata1$y, y2 = subdata2$y,
-                                       myColors = col[i - 1], alpha = 1, border = col[i - 1])                            
-                              
+                                       myColors = col[i - 1], alpha = 1, border = col[i - 1])
+
                             }
                           }
                         }
-                        
+
                         angles <- seq(0, 2 * pi, length = 360)
                         sapply(intervals, function(x) llines(x * sin(angles), x * cos(angles),
                                                              col = "grey85", lty = 5))
-                        
+
                         ## zero line if needed
                         if (!is.na(zero)) llines(intervals[zero] * sin(angles),
                                                  intervals[zero] * cos(angles), col = "grey85")
-                        
-                        
+
+
                         ## add axis lines
                         larrows(max(intervals) * -1, 0, max(intervals), 0, code = 3, length = 0.1)
                         larrows(0, max(intervals) * -1, 0, max(intervals), code = 3, length = 0.1)
-                        
-                        
+
+
                         ltext(0.7 * sin(pi * (angle.scale + 5) / 180) * max(intervals),
                               0.7 * cos(pi * (angle.scale + 5) / 180) * max(intervals),
                               quickText(pollutant, auto.text), srt = 0, cex = 0.8, pos = 4)
-                        
-                        
+
+
                         ltext(max(intervals) * -1 * 0.95, 0.07 * max(intervals), "W", cex = 0.7)
                         ltext(0.07 * max(intervals), max(intervals) * -1 * 0.95, "S", cex = 0.7)
                         ltext(0.07 * max(intervals), max(intervals) * 0.95, "N", cex = 0.7)
                         ltext(max(intervals) * 0.95, 0.07 * max(intervals), "E", cex = 0.7)
-                        
+
                         ## draw lines if fill = FALSE
                         if (!fill) {
                           for (i in seq_along(percentile)) {
@@ -499,37 +509,37 @@ percentileRose <- function (mydata, pollutant = "nox", wd = "wd", type = "defaul
                             subdata <- subset(results.grid[subscripts, ], percentile == value)
                             llines(subdata$x, subdata$y, col = col[i], lwd = extra.args$lwd)
                           }
-                          
+
                         }
-                        
+
                         ## add mean line
                         if (mean) {
                           subdata <- subset(results.grid[subscripts, ], percentile == 999)
                           llines(subdata$x, subdata$y, col = mean.col, lwd = mean.lwd, lty = mean.lty)
                         }
-                        
+
                         ltext(intervals * sin(pi * angle.scale / 180),
                               intervals * cos(pi * angle.scale / 180),
                               paste(labs, c("", "", rep("", 7))), cex = 0.7)
-                        
-                        
+
+
                       }, legend = legend)
-  
+
   #reset for extra.args
   xyplot.args<- listUpdate(xyplot.args, extra.args)
-  
+
   #plot
   plt <- do.call(xyplot, xyplot.args)
-  
-  
+
+
   ## output ####################################################################################
-  
+
   if (length(type) == 1) plot(plt) else plot(useOuterStrips(plt, strip = strip, strip.left = strip.left))
-  
+
   output <- list(plot = plt, data = newdata, call = match.call())
   class(output) <- "openair"
-  
-  
+
+
   invisible(output)
-  
+
 }
