@@ -89,6 +89,7 @@ quickText <- function(text, auto.text = TRUE){
     ans <- gsub("ch4", "' 'CH' [4] * '", ans)
     ans <- gsub("dgrC", "' * degree * 'C' '", ans)
     ans <- gsub("degreeC", "' * degree * 'C' '", ans)
+    ans <- gsub("deg. C", "' * degree * 'C' '", ans)
     ans <- gsub("degreesC", "' * degree * 'C' '", ans)
     ans <- gsub("degrees", "' * degree *'", ans)
     ans <- gsub("Delta", "' * Delta *'", ans)
@@ -105,6 +106,7 @@ quickText <- function(text, auto.text = TRUE){
     ans <- gsub("ng.m-3", "' * 'n' * 'g m' ^-3 *'", ans)
     ans <- gsub("ng m-3", "' * 'n' * 'g m' ^-3 *'", ans)
     ans <- gsub("ngm-3", "' * 'n' * 'g m' ^-3 *'", ans)
+    ans <- gsub("m/s2", "' 'm s' ^-2 *'", ans)
     ans <- gsub("m/s", "' 'm s' ^-1 *'", ans)
     ans <- gsub("m.s-1", "' 'm s' ^-1 *'", ans)
     ans <- gsub("m s-1", "' 'm s' ^-1 *'", ans)
